@@ -10,34 +10,35 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.20';
-$DATE = '2004/04/10';
+$VERSION = '0.21';
+$DATE = '2004/04/13';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.20 2004/04/10), 'revised 0.19'],
-    'MANIFEST' => [qw(0.20 2004/04/10), 'generated, replaces 0.19'],
-    'Makefile.PL' => [qw(0.20 2004/04/10), 'generated, replaces 0.19'],
-    'README' => [qw(0.20 2004/04/10), 'generated, replaces 0.19'],
-    'lib/Test/Tech.pm' => [qw(1.17 2004/04/08), 'unchanged'],
-    't/Test/Tech/Tech.d' => [qw(0.04 2004/04/09), 'unchanged'],
-    't/Test/Tech/Tech.pm' => [qw(0.01 2004/04/08), 'unchanged'],
-    't/Test/Tech/Tech.t' => [qw(0.17 2004/04/09), 'unchanged'],
-    't/Test/Tech/techA0.t' => [qw(0.11 2004/04/08), 'unchanged'],
+    'lib/Docs/Site_SVD/Test_Tech.pm' => [qw(0.21 2004/04/13), 'revised 0.20'],
+    'MANIFEST' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
+    'Makefile.PL' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
+    'README' => [qw(0.21 2004/04/13), 'generated, replaces 0.20'],
+    'lib/Test/Tech.pm' => [qw(1.18 2004/04/13), 'revised 1.17'],
+    't/Test/Tech/Tech.d' => [qw(0.05 2004/04/13), 'revised 0.04'],
+    't/Test/Tech/Tech.pm' => [qw(0.04 2004/04/13), 'revised 0.03'],
+    't/Test/Tech/Tech.t' => [qw(0.18 2004/04/13), 'revised 0.17'],
+    't/Test/Tech/techA0.t' => [qw(0.12 2004/04/13), 'revised 0.11'],
     't/Test/Tech/techA2.txt' => [qw(0.08 2004/04/07), 'unchanged'],
-    't/Test/Tech/techB0.t' => [qw(0.08 2004/04/08), 'unchanged'],
-    't/Test/Tech/techC0.t' => [qw(0.12 2004/04/08), 'unchanged'],
-    't/Test/Tech/techC2.txt' => [qw(0.09 2004/04/07), 'unchanged'],
-    't/Test/Tech/techD0.d' => [qw(0.05 2004/04/08), 'unchanged'],
+    't/Test/Tech/techB0.t' => [qw(0.09 2004/04/13), 'revised 0.08'],
+    't/Test/Tech/techC0.t' => [qw(0.13 2004/04/13), 'revised 0.12'],
+    't/Test/Tech/techC2.txt' => [qw(0.1 2004/04/13), 'revised 0.09'],
+    't/Test/Tech/techD0.d' => [qw(0.06 2004/04/13), 'revised 0.05'],
     't/Test/Tech/techD2.txt' => [qw(0.07 2003/09/15), 'unchanged'],
     't/Test/Tech/techD3.txt' => [qw(0.07 2003/09/15), 'unchanged'],
-    't/Test/Tech/techE0.t' => [qw(0.07 2004/04/08), 'unchanged'],
-    't/Test/Tech/techE2.txt' => [qw(0.17 2004/04/07), 'unchanged'],
-    't/Test/Tech/File/Package.pm' => [qw(1.15 2004/04/10), 'revised 1.14'],
-    't/Test/Tech/File/SmartNL.pm' => [qw(1.13 2004/04/10), 'unchanged'],
-    't/Test/Tech/Text/Scrub.pm' => [qw(1.11 2004/04/10), 'unchanged'],
-    't/Test/Tech/Data/Secs2.pm' => [qw(1.15 2004/04/10), 'new'],
+    't/Test/Tech/techE0.t' => [qw(0.08 2004/04/13), 'revised 0.07'],
+    't/Test/Tech/techE2.txt' => [qw(0.18 2004/04/13), 'revised 0.17'],
+    't/Test/Tech/File/Package.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
+    't/Test/Tech/File/SmartNL.pm' => [qw(1.13 2004/04/13), 'unchanged'],
+    't/Test/Tech/Text/Scrub.pm' => [qw(1.11 2004/04/13), 'unchanged'],
+    't/Test/Tech/Data/Secs2.pm' => [qw(1.16 2004/04/13), 'revised 1.15'],
+    't/Test/Tech/Data/SecsPack.pm' => [qw(0.02 2004/04/13), 'new'],
     't/Test/Tech/V001024/Test.pm' => [qw(1.25 2003/09/15), 'unchanged'],
     't/Test/Tech/V001015/Test.pm' => [qw(1.16 2003/09/15), 'unchanged'],
 
@@ -66,11 +67,11 @@ use vars qw(%INVENTORY);
 
  Test::Tech - Extends the Test program module
 
- Revision: T
+ Revision: U
 
- Version: 0.20
+ Version: 0.21
 
- Date: 2004/04/10
+ Date: 2004/04/13
 
  Prepared for: General Public 
 
@@ -137,7 +138,7 @@ session using the methods under test
 
 =head2 1.3 Document overview.
 
-This document releases Test::Tech version 0.20
+This document releases Test::Tech version 0.21
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -152,7 +153,7 @@ system file specification.
 
 This document releases the file 
 
- Test-Tech-0.20.tar.gz
+ Test-Tech-0.21.tar.gz
 
 found at the following repository(s):
 
@@ -224,28 +225,29 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_Tech.pm                               0.20    2004/04/10 revised 0.19
- MANIFEST                                                     0.20    2004/04/10 generated, replaces 0.19
- Makefile.PL                                                  0.20    2004/04/10 generated, replaces 0.19
- README                                                       0.20    2004/04/10 generated, replaces 0.19
- lib/Test/Tech.pm                                             1.17    2004/04/08 unchanged
- t/Test/Tech/Tech.d                                           0.04    2004/04/09 unchanged
- t/Test/Tech/Tech.pm                                          0.01    2004/04/08 unchanged
- t/Test/Tech/Tech.t                                           0.17    2004/04/09 unchanged
- t/Test/Tech/techA0.t                                         0.11    2004/04/08 unchanged
+ lib/Docs/Site_SVD/Test_Tech.pm                               0.21    2004/04/13 revised 0.20
+ MANIFEST                                                     0.21    2004/04/13 generated, replaces 0.20
+ Makefile.PL                                                  0.21    2004/04/13 generated, replaces 0.20
+ README                                                       0.21    2004/04/13 generated, replaces 0.20
+ lib/Test/Tech.pm                                             1.18    2004/04/13 revised 1.17
+ t/Test/Tech/Tech.d                                           0.05    2004/04/13 revised 0.04
+ t/Test/Tech/Tech.pm                                          0.04    2004/04/13 revised 0.03
+ t/Test/Tech/Tech.t                                           0.18    2004/04/13 revised 0.17
+ t/Test/Tech/techA0.t                                         0.12    2004/04/13 revised 0.11
  t/Test/Tech/techA2.txt                                       0.08    2004/04/07 unchanged
- t/Test/Tech/techB0.t                                         0.08    2004/04/08 unchanged
- t/Test/Tech/techC0.t                                         0.12    2004/04/08 unchanged
- t/Test/Tech/techC2.txt                                       0.09    2004/04/07 unchanged
- t/Test/Tech/techD0.d                                         0.05    2004/04/08 unchanged
+ t/Test/Tech/techB0.t                                         0.09    2004/04/13 revised 0.08
+ t/Test/Tech/techC0.t                                         0.13    2004/04/13 revised 0.12
+ t/Test/Tech/techC2.txt                                       0.1     2004/04/13 revised 0.09
+ t/Test/Tech/techD0.d                                         0.06    2004/04/13 revised 0.05
  t/Test/Tech/techD2.txt                                       0.07    2003/09/15 unchanged
  t/Test/Tech/techD3.txt                                       0.07    2003/09/15 unchanged
- t/Test/Tech/techE0.t                                         0.07    2004/04/08 unchanged
- t/Test/Tech/techE2.txt                                       0.17    2004/04/07 unchanged
- t/Test/Tech/File/Package.pm                                  1.15    2004/04/10 revised 1.14
- t/Test/Tech/File/SmartNL.pm                                  1.13    2004/04/10 unchanged
- t/Test/Tech/Text/Scrub.pm                                    1.11    2004/04/10 unchanged
- t/Test/Tech/Data/Secs2.pm                                    1.15    2004/04/10 new
+ t/Test/Tech/techE0.t                                         0.08    2004/04/13 revised 0.07
+ t/Test/Tech/techE2.txt                                       0.18    2004/04/13 revised 0.17
+ t/Test/Tech/File/Package.pm                                  1.16    2004/04/13 revised 1.15
+ t/Test/Tech/File/SmartNL.pm                                  1.13    2004/04/13 unchanged
+ t/Test/Tech/Text/Scrub.pm                                    1.11    2004/04/13 unchanged
+ t/Test/Tech/Data/Secs2.pm                                    1.16    2004/04/13 revised 1.15
+ t/Test/Tech/Data/SecsPack.pm                                 0.02    2004/04/13 new
  t/Test/Tech/V001024/Test.pm                                  1.25    2003/09/15 unchanged
  t/Test/Tech/V001015/Test.pm                                  1.16    2003/09/15 unchanged
 
@@ -579,6 +581,23 @@ to test C<Test::Tech>, the prereq is processed too late.
 Added C<Data::Secs2> to the test library so the test
 will run. 
 
+=item Test-Tech-0.21
+
+For C<Test> module, version 1.20 or greater, changed so it sents failure messages
+when skip flag turned on for C<&Test::Tech::ok> and C<&Test::Tech::ok>
+out C<$Test::TESTERR> instead of C<$Test::TESTOUT>.
+
+For C<&Test::Tech::finish> automatically generate failure messages
+for all missing (not performed) test when the skip rest of tests
+flag is on.
+
+The C<FindBIN> that runs fine on Win because Win file spec is case insensitive
+and Unix whats case sensitive C<FindBin> was fixed with on test C<Test::Test>.
+However, overlooked all the test scripts that the top test script runs,
+grabs the output and compares to expected ouput stored in files.
+Corrected the C<FindBin> for following test software: 
+C<TechA0.t TechB0.t TechC0.t TechD0.d TechE0.t>
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -617,13 +636,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
-Right click on 'Test-Tech-0.20.tar.gz' and download to a temporary
+Right click on 'Test-Tech-0.21.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip Test-Tech-0.20.tar.gz
- tar -xf Test-Tech-0.20.tar
+ gunzip Test-Tech-0.21.tar.gz
+ tar -xf Test-Tech-0.21.tar
  perl Makefile.PL
  $make test
  $make install
@@ -636,7 +655,9 @@ not install, download and install unxutils from
 
 =item Prerequistes.
 
- 'Data::Secs2' => '0.01'
+ 'Data::Secs2' => '0.03',
+ 'Data::SecsPack' => '0.01',
+ 'Test' => '1.20',
 
 
 =item Security, privacy, or safety precautions.
@@ -738,11 +759,11 @@ __DATA__
 DISTNAME: Test-Tech^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.20^
+VERSION : 0.21^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.19^
-REVISION: T^
+PREVIOUS_RELEASE: 0.20^
+REVISION: U^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: 
@@ -777,6 +798,7 @@ lib/File/Package.pm => t/Test/Tech/File/Package.pm
 lib/File/SmartNL.pm => t/Test/Tech/File/SmartNL.pm
 lib/Text/Scrub.pm => t/Test/Tech/Text/Scrub.pm
 lib/Data/Secs2.pm => t/Test/Tech/Data/Secs2.pm
+lib/Data/SecsPack.pm => t/Test/Tech/Data/SecsPack.pm
 ^
 
 REPLACE:
@@ -784,7 +806,11 @@ t/Test/Tech/V001024/*
 t/Test/Tech/V001015/*
 ^
 
-PREREQ_PM: 'Data::Secs2' => '0.01'^
+PREREQ_PM: 
+'Data::Secs2' => '0.03',
+'Data::SecsPack' => '0.01',
+'Test' => '1.20',
+^
 README_PODS: lib/Test/Tech.pm^
 
 TESTS: t/Test/Tech/Tech.t^
@@ -1119,6 +1145,23 @@ to test C<Test::Tech>, the prereq is processed too late.
 Added C<Data::Secs2> to the test library so the test
 will run. 
 
+\=item Test-Tech-0.21
+
+For C<Test> module, version 1.20 or greater, changed so it sents failure messages
+when skip flag turned on for C<&Test::Tech::ok> and C<&Test::Tech::ok>
+out C<$Test::TESTERR> instead of C<$Test::TESTOUT>.
+
+For C<&Test::Tech::finish> automatically generate failure messages
+for all missing (not performed) test when the skip rest of tests
+flag is on.
+
+The C<FindBIN> that runs fine on Win because Win file spec is case insensitive
+and Unix whats case sensitive C<FindBin> was fixed with on test C<Test::Test>.
+However, overlooked all the test scripts that the top test script runs,
+grabs the output and compares to expected ouput stored in files.
+Corrected the C<FindBin> for following test software: 
+C<TechA0.t TechB0.t TechC0.t TechD0.d TechE0.t>
+
 \=back
 
 ^
