@@ -4,7 +4,7 @@
 #
 package  Test::Tech;
 
-use 5.001;
+# use 5.001;
 use strict;
 use warnings;
 use warnings::register;
@@ -13,8 +13,8 @@ use Test ();   # do not import the "Test" subroutines
 use Data::Secs2 qw(stringify);
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.16';
-$DATE = '2004/04/07';
+$VERSION = '1.18';
+$DATE = '2004/04/13';
 $FILE = __FILE__;
 
 use vars qw(@ISA @EXPORT_OK);
@@ -86,22 +86,35 @@ sub new
 #####
 # Restore the Test:: moduel variable back to where they were when found
 #
-sub DESTROY
+sub finish
 {
     my $self = UNIVERSAL::isa($_[0],__PACKAGE__) ? shift @_ : $tech_p;
 
+    return undef unless $Test::TESTOUT;  # if IO::Handle object may be destroyed and undef
+    return undef unless $Test::planned;  
+
+    my $missing = $self->{last_test} + 1;
+    $self->{test_name} = '';
+    while($missing <= $self->{num_tests}) {
+        if($self->{Skip_Diag}) {
+            print $Test::TESTOUT "not ok $missing Not Performed # missing\n";
+            if( 1.20 < $Test::VERSION ) {
+                print $Test::TESTERR "# Test $missing got:\n";
+                print $Test::TESTERR "# Expected: (Missing. $self->{Skip_Diag})\n";
+            }
+            else {
+                print $Test::TESTOUT "# Test $missing got:\n";
+                print $Test::TESTOUT "# Expected: (Missing. $self->{Skip_Diag})\n";
+            }
+        }
+        push @{$self->{missed}}, $missing++;
+    }
+
     $Test::TESTOUT = $self->{TestDefault}->{TESTOUT};
     $Test::TestLevel = $self->{TestDefault}->{TestLevel};
     $Test::ONFAIL = $self->{TestDefault}->{ONFAIL};
     $Test::TESTERR = $self->{TestDefault}->{TESTERR} if defined $Test::TESTERR;
 
-    return unless $Test::TESTOUT;  # if IO::Handle object may be destroyed and undef
-    return unless $self->{last_test} && $self->{num_tests};  
-
-    my $missing = $self->{last_test} + 1;
-    while($missing <= $self->{num_tests}) {
-         push @{$self->{missed}}, $missing++;
-    }
     if(@{$self->{unplanned}}) {
         print $Test::TESTOUT '# Extra  : ' . (join ' ', @{$self->{unplanned}}) . "\n";
     }
@@ -122,12 +135,22 @@ sub DESTROY
 
     my $passed =  @{$self->{passed}};
     print $Test::TESTOUT '# Passed : ' . "$passed/$total " . ((100*$passed)/$total) . "%\n" if $total;
+
+    ######
+    # Only once per test run.
+    #
+    $Test::planned = 0;
+
+    return ($total,$self->{unplanned},$self->{missed},$self->{skipped},$self->{passed},$self->{failed})
+          if wantarray;
+
+    $passed ? 1 : 0;
 }
 
-# *finish = &*Test::Tech::DESTORY; # finish is alias for DESTORY
-sub finish 
+# *finish = &*Test::Tech::DESTORY; # DESTORY is alias for finish
+sub DESTORY 
 {
-    Test::Tech::DESTROY( @_ );
+    finish( @_ );
 
 }
 
@@ -227,8 +250,14 @@ sub ok
        &Test::skip( 1, 0, '');
        if($self->{Skip_Diag}) {
            my $test_number = $Test::ntest - 1;
-           print $Test::TESTOUT "# Test $test_number got:\n";
-           print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
+           if( 1.20 < $Test::VERSION ) {
+               print $Test::TESTERR "# Test $test_number got:\n";
+               print $Test::TESTERR "# Expected: ($self->{Skip_Diag})\n";
+           }
+           else {
+               print $Test::TESTOUT "# Test $test_number got:\n";
+               print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
+           }
        }
        return 1; 
    }
@@ -275,8 +304,14 @@ sub skip
        &Test::skip( 1, 0, '');
        if($self->{Skip_Diag}) {
            my $test_number = $Test::ntest - 1;
-           print $Test::TESTOUT "# Test $test_number got:\n";
-           print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
+           if( 1.20 < $Test::VERSION ) {
+               print $Test::TESTERR "# Test $test_number got:\n";
+               print $Test::TESTERR "# Expected: ($self->{Skip_Diag})\n";
+           }
+           else {
+               print $Test::TESTOUT "# Test $test_number got:\n";
+               print $Test::TESTOUT "# Expected: ($self->{Skip_Diag})\n";
+           }
        }
        return 1; 
    }
@@ -529,19 +564,19 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
 
  $success = plan(@args);
 
- $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
- $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, {@options});
- $test_ok = ok($actual_results, $expected_results, $diagnostic, [@options]);
- $test_ok = ok($actual_results, $expected_results, $diagnostic, {@options});
  $test_ok = ok($actual_results, $expected_results, [@options]);
  $test_ok = ok($actual_results, $expected_results, {@options});
+ $test_ok = ok($actual_results, $expected_results, $diagnostic, [@options]);
+ $test_ok = ok($actual_results, $expected_results, $diagnostic, {@options});
+ $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
+ $test_ok = ok($actual_results, $expected_results, $diagnostic, $test_name, {@options});
 
- $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, [@options]);
- $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, {@options});
- $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, [@options]);
- $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, {@options});
  $test_ok = skip($skip_test, $actual_results,  $expected_results, [@options]);
  $test_ok = skip($skip_test, $actual_results,  $expected_results, {@options});
+ $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, [@options]);
+ $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, {@options});
+ $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, [@options]);
+ $test_ok = skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, {@options});
 
  $state = skip_tests( $on_off, $skip_diagnostic);
  $state = skip_tests( $on_off );
@@ -551,7 +586,8 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  $string = $tech->stringify($var, [@options]);
  $string = $tech->stringify($var, {@options});
 
- finish( );
+ (@stats) = finish( );
+ $num_passed = finish( );
 
  demo($quoted_expression, @expression)
 
@@ -561,31 +597,33 @@ Test::Tech - adds skip_tests and test data structures capabilities to the "Test"
  # 
  $tech = new Test::Tech;
 
- $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
- $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, $test_name, {@options]};
- $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, [@options]);
- $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, {@options]};
  $test_ok = $tech->ok($actual_results, $expected_results, [@options]);
  $test_ok = $tech->ok($actual_results, $expected_results, {@options]};
+ $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, [@options]);
+ $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, {@options]};
+ $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, $test_name, [@options]);
+ $test_ok = $tech->ok($actual_results, $expected_results, $diagnostic, $test_name, {@options]};
 
- $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, [@options]);
- $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, {@options});
- $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, [@options]);
- $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, {@options});
  $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, [@options]);
  $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, {@options});
+ $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, [@options]);
+ $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, {@options});
+ $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, [@options]);
+ $test_ok = $tech->skip($skip_test, $actual_results,  $expected_results, $diagnostic, $test_name, {@options});
 
- $state = skip_tests( $on_off, $skip_diagnostic );
- $state  = $tech->skip_tests( $on_off );
  $state  = $tech->skip_tests( );
+ $state  = $tech->skip_tests( $on_off );
+ $state = skip_tests( $on_off, $skip_diagnostic );
 
- $string = $tech->stringify($var, @options); # imported from Data::Secs2
+ $string = $tech->stringify($var); # imported from Data::Secs2
+ $string = $tech->stringify($var, @options); 
  $string = $tech->stringify($var, [@options]);
  $string = $tech->stringify($var, {@options});
 
  $new_value = $tech->tech_config($key, $old_value);
 
- $tech->finish();
+ (@stats) = $tech->finish( );
+ $num_passed = $tech->finish( );
 
  $tech->demo($quoted_expression, @expression)
 
@@ -779,23 +817,74 @@ for the top level 'Test', the "L<Test|Test>" module.
 
 =head2 finish subroutine
 
- finish();
+ (@stats) = $tech->finish( );
+ $num_passed = $tech->finish( );
 
-The finish() subroutine/method outputs the test steps
-that are missing, failed, unplanned and other statistics.
+The C<finish()> subroutine/method restores changes made
+to the C<Test> module module made by the 
+C<tech_config> subroutine/method or directly.
 
-The finish() subroutine/method restores changes made
-to the 'Test' module module made by the 
-'tech_config' subroutine/method or directly.
-
-When the 'new' subroutine/method creates a 'Test::Tech'
-object, the Perl will automatically run the
-'finish' method when that object is destoried.
+When the C<new> subroutine/method creates a C<Test::Tech>
+object.
+Perl will automatically run the
+C<finish()> method when that object is destoried.
 
 Running the 'finish' method without a class or object,
 restores the 'Test' module to the values when
 the 'Test::Tech' module was loaded.
 
+When used in an array context
+the C<finish()> subroutine/method 
+returns the C<@stats> array.
+The C<@stats> array consists of the following:
+
+The C<finish()> subroutine resets the C<last_test> and
+to zero and will returns undef without
+performing any of the above. 
+The C<finish()> subroutine will not be active again
+until a new test run is start with  C<&Test::Tech::plan>
+and the first test performed by C<&Test::Tech::ok> or
+C<&Test::Tech::skip>.
+
+In a scalar contents, the C<finish()> subroutine/method outputs
+a 1 for sucess and 0 for failure.
+In an array context,
+the C<finish()> subroutine/method outputs C<@stats>
+array that consists of the following:
+
+=over 4
+
+=item 0
+
+number of tests
+
+This is calculated as the maximum of the tests planned
+and the highest test number. From the maximum, substract
+the skipped tests. In other words, the sum of the missed,
+passed and failed test steps.
+
+=item 1
+
+reference to the unplanned test steps
+
+=item 2
+
+reference to the missed test steps
+
+=item 3
+
+reference to the skipped test steps
+
+=item 4
+
+reference to the passed test steps
+
+=item 5
+
+reference to the failed test steps
+
+=back
+
 =head2 demo subroutine
 
  demo($quoted_expression, @expression)
@@ -846,184 +935,84 @@ follow on the next lines. For example,
  use strict;
  use warnings;
  use warnings::register;
-
  use vars qw($VERSION $DATE);
- $VERSION = '0.09';
- $DATE = '2003/09/20';
+ $VERSION = '0.12';
+ $DATE = '2004/04/13';
 
- use Cwd;
- use File::Spec;
-
- ######
- #
- # T:
- #
- # use a BEGIN block so we print our plan before Module Under Test is loaded
- #
  BEGIN {
-
-    use vars qw($t $__restore_dir__ @__restore_inc__);
-
-    ########
-    # Working directory is that of the script file
-    #
+    use FindBin;
+    use File::Spec;
+    use Cwd;
+    use vars qw( $__restore_dir__ );
     $__restore_dir__ = cwd();
-    my ($vol, $dirs) = File::Spec->splitpath(__FILE__);
+    my ($vol, $dirs) = File::Spec->splitpath($FindBin::Bin,'nofile');
     chdir $vol if $vol;
     chdir $dirs if $dirs;
-    ($vol, $dirs) = File::Spec->splitpath(cwd(), 'nofile'); # absolutify
+    use lib $FindBin::Bin;
 
-    #######
-    # Add the library of the unit under test (UUT) to @INC
-    # It will be found first because it is first in the include path
-    #
-    @__restore_inc__ = @INC;
-
-    ######
-    # Find root path of the t directory
-    #
-    my @updirs = File::Spec->splitdir( $dirs );
-    while(@updirs && $updirs[-1] ne 't' ) { 
-        chdir File::Spec->updir();
-        pop @updirs;
-    };
-    chdir File::Spec->updir();
-    my $lib_dir = cwd();
-
-    #####
-    # Add this to the include path. Thus modules that start with t::
-    # will be found.
-    # 
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;  # include the current test directory
-
-    #####
-    # Add lib to the include path so that modules under lib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'lib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-
-    #####
-    # Add tlib to the include path so that modules under tlib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'tlib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-    chdir $dirs if $dirs;
-
-    #######
     # Add the directory with "Test.pm" version 1.15 to the front of @INC
-    #
-    # Thus, load Test::Tech, will find Test.pm 1.15 first
-    #
+    # Thus, 'use Test;' in  Test::Tech, will find Test.pm 1.15 first
     unshift @INC, File::Spec->catdir ( cwd(), 'V001015'); 
 
-    ########
     # Create the test plan by supplying the number of tests
     # and the todo tests
-    #
     require Test::Tech;
     Test::Tech->import( qw(plan ok skip skip_tests tech_config finish) );
     plan(tests => 8, todo => [4, 8]);
-
  }
 
  END {
-
-    #########
     # Restore working directory and @INC back to when enter script
-    #
-    @INC = @__restore_inc__;
+    @INC = @lib::ORIG_INC;
     chdir $__restore_dir__;
  }
 
  my $x = 2;
  my $y = 3;
 
- #########
  #  ok:  1 - Using Test 1.15
- #
  ok( $Test::VERSION, '1.15', '', 'Test version');
 
- #########
- #  ok:  2 - Do not skip rest
- #
- skip_tests( 1 ) unless ok(
+ skip_tests( 1 ) unless ok( #  ok:  2 - Do not skip rest
      $x + $y, # actual results
      5, # expected results
      '', 'Pass test'); 
 
- #########
- #
  #  ok:  3
  #
- # R:
- #
  skip( 1, # condition to skip test   
        ($x*$y*2), # actual results
        6, # expected results
        '','Skipped tests');
 
- #######
- #  zyw feature
- #  Under development, i.e todo
- #
- #  ok:  4
- #
- # R:
- #
- ok( $x*$y*2, # actual results
-           6, # expected results
-           '','Todo Test that Fails');
- ####
- # 
- #  ok:  5
- #
- # R:
- #
- skip_tests(1) unless ok(
+ #  zyw featureUnder development, i.e todo
+ ok( #  ok:  4
+     $x*$y*2, # actual results
+     6, # expected results
+     '','Todo Test that Fails');
+
+ skip_tests(1) unless ok( #  ok:  5
      $x + $y, # actual results
      6, # expected results
      '','Failed test that skips the rest'); 
 
- ####
- #
- #  ok:  6
- #
- # R:
- #
- ok( $x + $y + $x, # actual results
-           9, # expected results
-           '', 'A test to skip');
+ ok( #  ok:  6
+     $x + $y + $x, # actual results
+     9, # expected results
+     '', 'A test to skip');
 
- ####
- # 
- #  ok:  7
- # 
- # R:
- #
- ok( $x + $y + $x + $y, # actual results
-           10, # expected results
-           '', 'A not skip to skip');
+ ok( #  ok:  7
+     $x + $y + $x + $y, # actual results
+     10, # expected results
+     '', 'A not skip to skip');
 
- ####
- # 
- #  ok:  8
- # 
- # R:
- #
  skip_tests(0);
- ok( $x*$y*2, # actual results
-           12, # expected results
-           '', 'Stop skipping tests. Todo Test that Passes');
+ ok( #  ok:  8
+     $x*$y*2, # actual results
+          12, # expected results
+          '', 'Stop skipping tests. Todo Test that Passes');
 
- #########
- #  ok:  9
- #
- ok(
+ ok( #  ok:  9
      $x * $y, # actual results
      6, # expected results
      {name => 'Unplanned pass test'}); 
@@ -1032,14 +1021,6 @@ follow on the next lines. For example,
 
  __END__
 
- =head1 NAME
-
- techA1.t - test script for Test::Tech
-
- =head1 SYNOPSIS
-
-  techA1.t 
-
  =head1 COPYRIGHT
 
  This test script is public domain.
@@ -1087,81 +1068,26 @@ follow on the next lines. For example,
  use warnings::register;
 
  use vars qw($VERSION $DATE);
- $VERSION = '0.1';
- $DATE = '2003/09/20';
+ $VERSION = '0.13';
+ $DATE = '2004/04/13';
 
- use Cwd;
- use File::Spec;
-
- ######
- #
- # T:
- #
- # use a BEGIN block so we print our plan before Module Under Test is loaded
- #
- ######
- #
- # T:
- #
- # use a BEGIN block so we print our plan before Module Under Test is loaded
- #
- BEGIN { 
-    use vars qw($t $__restore_dir__ @__restore_inc__);
-
-    ########
-    # Working directory is that of the script file
-    #
+ BEGIN {
+    use FindBin;
+    use File::Spec;
+    use Cwd;
+    use vars qw( $__restore_dir__ );
     $__restore_dir__ = cwd();
-    my ($vol, $dirs) = File::Spec->splitpath(__FILE__);
+    my ($vol, $dirs) = File::Spec->splitpath($FindBin::Bin,'nofile');
     chdir $vol if $vol;
     chdir $dirs if $dirs;
-    ($vol, $dirs) = File::Spec->splitpath(cwd(), 'nofile'); # absolutify
+    use lib $FindBin::Bin;
 
-    #######
-    # Add the library of the unit under test (UUT) to @INC
-    # It will be found first because it is first in the include path
-    #
-    @__restore_inc__ = @INC;
+    # Add the directory with "Test.pm" version 1.24 to the front of @INC
+    # Thus, load Test::Tech, will find Test.pm 1.24 first
+    unshift @INC, File::Spec->catdir ( cwd(), 'V001024'); 
 
-    ######
-    # Find root path of the t directory
-    #
-    my @updirs = File::Spec->splitdir( $dirs );
-    while(@updirs && $updirs[-1] ne 't' ) { 
-        chdir File::Spec->updir();
-        pop @updirs;
-    };
-    chdir File::Spec->updir();
-    my $lib_dir = cwd();
-
-    #####
-    # Add this to the include path. Thus modules that start with t::
-    # will be found.
-    # 
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;  # include the current test directory
-
-    #####
-    # Add lib to the include path so that modules under lib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'lib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-
-    #####
-    # Add tlib to the include path so that modules under tlib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'tlib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-    chdir $dirs if $dirs;
-
-    ########
     # Create the test plan by supplying the number of tests
     # and the todo tests
-    #
     require Test::Tech;
     Test::Tech->import( qw(plan ok skip skip_tests tech_config finish) );
     plan(tests => 2, todo => [1]);
@@ -1169,41 +1095,27 @@ follow on the next lines. For example,
  }
 
  END {
-
-    #########
     # Restore working directory and @INC back to when enter script
-    #
-    @INC = @__restore_inc__;
+    @INC = @lib::ORIG_INC;
     chdir $__restore_dir__;
  }
 
- ######
- #
- # Test 1.24 error goes to the STDERR
+ # 1.24 error goes to the STDERR
  # while 1.15 goes to STDOUT
- #
  # redirect STDERR to the STDOUT
- # 
  tech_config('Test.TESTERR', \*STDOUT);
 
  my $x = 2;
  my $y = 3;
 
- ########
- #  xy feature
- #  Under development, i.e todo
- #
- #  ok:  1
- #
- ok( [$x+$y,$y-$x], # actual results
+ #  xy feature Under development, i.e todo
+ ok( #  ok:  1
+     [$x+$y,$y-$x], # actual results
      [5,1], # expected results
      '', 'Todo test that passes');
 
- ########
- #
- #  ok:  2
- #
- ok( [$x+$y,$x*$y], # actual results
+ ok( #  ok:  2
+     [$x+$y,$x*$y], # actual results
      [6,5], # expected results
      '', 'Test that fails');
 
@@ -1211,14 +1123,6 @@ follow on the next lines. For example,
 
  __END__
 
- =head1 NAME
-
- techC0.t - test script for Test::Tech
-
- =head1 SYNOPSIS
-
-  techC0.t 
-
  =head1 COPYRIGHT
 
  This test script is public domain.
@@ -1235,215 +1139,16 @@ follow on the next lines. For example,
  '1..2 todo 1;
  ok 1 - Todo test that passes  # (xxxx.t at line 000 TODO?!)
  not ok 2 - Test that fails 
- # Test 2 got: 'L[4]
-   A[0] 
-   A[5] ARRAY
-   A[1] 5
-   A[1] 6
+ # Test 2 got: 'U1[1] 80
+ U1[2] 5 6
  ' (xxxx.t at line 000)
- #   Expected: 'L[4]
-   A[0] 
-   A[5] ARRAY
-   A[1] 6
-   A[1] 5
+ #   Expected: 'U1[1] 80
+ U1[2] 6 5
  '
  # Failed : 2
  # Passed : 1/2 50%
  '
 
- => $snl->fin('techE0.t')
- '#!perl
- #
- #
- use 5.001;
- use strict;
- use warnings;
- use warnings::register;
-
- use vars qw($VERSION $DATE);
- $VERSION = '0.06';
- $DATE = '2003/09/20';
-
- use Cwd;
- use File::Spec;
-
- ######
- #
- # T:
- #
- # use a BEGIN block so we print our plan before Module Under Test is loaded
- #
- BEGIN {
-
-    use vars qw($t $__restore_dir__ @__restore_inc__);
-
-    ########
-    # Working directory is that of the script file
-    #
-    $__restore_dir__ = cwd();
-    my ($vol, $dirs) = File::Spec->splitpath(__FILE__);
-    chdir $vol if $vol;
-    chdir $dirs if $dirs;
-    ($vol, $dirs) = File::Spec->splitpath(cwd(), 'nofile'); # absolutify
-
-    #######
-    # Add the library of the unit under test (UUT) to @INC
-    # It will be found first because it is first in the include path
-    #
-    @__restore_inc__ = @INC;
-
-    ######
-    # Find root path of the t directory
-    #
-    my @updirs = File::Spec->splitdir( $dirs );
-    while(@updirs && $updirs[-1] ne 't' ) { 
-        chdir File::Spec->updir();
-        pop @updirs;
-    };
-    chdir File::Spec->updir();
-    my $lib_dir = cwd();
-
-    #####
-    # Add this to the include path. Thus modules that start with t::
-    # will be found.
-    # 
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;  # include the current test directory
-
-    #####
-    # Add lib to the include path so that modules under lib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'lib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-
-    #####
-    # Add tlib to the include path so that modules under tlib at the
-    # same level as t, will be found
-    #
-    $lib_dir = File::Spec->catdir( cwd(), 'tlib' );
-    $lib_dir =~ s|/|\\|g if $^O eq 'MSWin32';  # microsoft abberation
-    unshift @INC, $lib_dir;
-    chdir $dirs if $dirs;
-    #######
-    # Add the directory with "Test.pm" version 1.15 to the front of @INC
-    #
-    # Thus, load Test::Tech, will find Test.pm 1.15 first
-    #
-    unshift @INC, File::Spec->catdir ( cwd(), 'V001024'); 
-
-    ########
-    # Create the test plan by supplying the number of tests
-    # and the todo tests
-    #
-    require Test::Tech;
-    Test::Tech->import( qw(plan ok skip skip_tests tech_config finish) );
-    plan(tests => 8, todo => [4, 8]);
-
- }
-
- END {
-
-    #########
-    # Restore working directory and @INC back to when enter script
-    #
-    @INC = @__restore_inc__;
-    chdir $__restore_dir__;
- }
-
- ######
- #
- # 1.24 error goes to the STDERR
- # while 1.15 goes to STDOUT
- #
- # redirect STDERR to the STDOUT
- # 
- tech_config('Test.TESTERR', \*STDOUT);
-
- my $x = 2;
- my $y = 3;
-
- #########
- #  ok:  1 - Using Test 1.24
- #
- ok( $Test::VERSION, '1.24', '', 'Test version');
-
- #########
- #  ok:  2 - Do not skip rest
- #
- skip_tests( 1 ) unless ok(
-     $x + $y, # actual results
-     5, # expected results
-     {name => 'Pass test'} ); 
-
- #########
- #
- #  ok:  3
- #
- # R:
- #
- skip( 1, # condition to skip test   
-       ($x*$y*2), # actual results
-       6, # expected results
-       {name => 'Skipped tests'});
-
- #######
- #  zyw feature
- #  Under development, i.e todo
- #
- #  ok:  4
- #
- # R:
- #
- ok( $x*$y*2, # actual results
-           6, # expected results
-           [name => 'Todo Test that Fails',
-            diagnostic => 'Should Fail']);
- ####
- # 
- #  ok:  5
- #
- # R:
- #
- skip_tests(1,'Skip test on') unless ok(
-     $x + $y, # actual results
-     6, # expected results
-     [diagnostic => 'Should Turn on Skip Test', 
-      name => 'Failed test that skips the rest']); 
-
- ####
- #
- #  ok:  6
- #
- # R:
- #
- ok( $x + $y + $x, # actual results
-           9, # expected results
-           '', 'A test to skip');
-
- finish() # pick up stats
-
- __END__
-
- =head1 NAME
-
- techB1.t - test script for Test::Tech
-
- =head1 SYNOPSIS
-
-  techB1.t 
-
- =head1 COPYRIGHT
-
- This test script is public domain.
-
- =cut
-
- ## end of test script file ##
-
- '
-
  =>     $actual_results = `perl techE0.t`;
  =>     $snl->fout('tech1.txt', $actual_results);
  => $s->scrub_probe($s->scrub_file_line($actual_results))
@@ -1460,29 +1165,38 @@ follow on the next lines. For example,
  ok 6 - A test to skip  # skip
  # Test 6 got:
  # Expected: (Skip test on)
+ not ok 7 Not Performed # missing
+ # Test 7 got:
+ # Expected: (Missing. Skip test on)
+ not ok 8 Not Performed # missing
+ # Test 8 got:
+ # Expected: (Missing. Skip test on)
  # Missing: 7 8
  # Skipped: 3 6
- # Failed : 4 5
+ # Failed : 4 5 7 8
  # Passed : 2/6 33%
  '
 
  => my $tech = new Test::Tech
- => $tech->tech_config('Test.TestLevel')
+ => $tech->tech_config('Test.ONFAIL')
  undef
 
- => $tech->tech_config('Test.TestLevel', 2)
+ => $tech->tech_config('Test.ONFAIL',0)
  undef
 
- => $tech->tech_config('Test.TestLevel')
- 2
+ => $tech->tech_config('Test.ONFAIL')
+ 0
 
- => $Test::TestLevel
- 2
+ => $Test::ONFAIL
+ 0
 
- => $tech->finish( )
- => $Test::TestLevel
- undef
+ =>      $tech->finish( );
+ =>      $Test::planned = 1;  # keep going
+ => $tech->tech_config('Test.ONFAIL')
+ 0
 
+ => unlink 'tech1.txt'
+ => unlink 'tech1.txt'
 
 =head1 QUALITY ASSURANCE
 
